@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -34,6 +34,9 @@ from .admin import (
     ListTopicsResponse,
     ListTopicSubscriptionsRequest,
     ListTopicSubscriptionsResponse,
+    OperationMetadata,
+    SeekSubscriptionRequest,
+    SeekSubscriptionResponse,
     TopicPartitions,
     UpdateReservationRequest,
     UpdateSubscriptionRequest,
@@ -114,6 +117,9 @@ __all__ = (
     "ListTopicsResponse",
     "ListTopicSubscriptionsRequest",
     "ListTopicSubscriptionsResponse",
+    "OperationMetadata",
+    "SeekSubscriptionRequest",
+    "SeekSubscriptionResponse",
     "TopicPartitions",
     "UpdateReservationRequest",
     "UpdateSubscriptionRequest",
