@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -228,6 +234,7 @@ def test_topic_stats_service_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -245,6 +252,7 @@ def test_topic_stats_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -262,6 +270,7 @@ def test_topic_stats_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -291,6 +300,25 @@ def test_topic_stats_service_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -368,6 +396,7 @@ def test_topic_stats_service_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -402,6 +431,7 @@ def test_topic_stats_service_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -424,6 +454,7 @@ def test_topic_stats_service_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -538,6 +569,7 @@ def test_topic_stats_service_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -576,6 +608,7 @@ def test_topic_stats_service_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -596,6 +629,7 @@ def test_topic_stats_service_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -634,6 +668,7 @@ def test_topic_stats_service_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -773,7 +808,7 @@ def test_compute_message_stats_field_headers():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeMessageStatsRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -791,7 +826,7 @@ def test_compute_message_stats_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -805,7 +840,7 @@ async def test_compute_message_stats_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeMessageStatsRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -825,7 +860,7 @@ async def test_compute_message_stats_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -927,7 +962,7 @@ def test_compute_head_cursor_field_headers():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeHeadCursorRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -945,7 +980,7 @@ def test_compute_head_cursor_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -959,7 +994,7 @@ async def test_compute_head_cursor_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeHeadCursorRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -979,7 +1014,7 @@ async def test_compute_head_cursor_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -1081,7 +1116,7 @@ def test_compute_time_cursor_field_headers():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeTimeCursorRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1099,7 +1134,7 @@ def test_compute_time_cursor_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -1113,7 +1148,7 @@ async def test_compute_time_cursor_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = topic_stats.ComputeTimeCursorRequest()
 
-    request.topic = "topic/value"
+    request.topic = "topic_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1133,7 +1168,7 @@ async def test_compute_time_cursor_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "topic=topic/value",
+        "topic=topic_value",
     ) in kw["metadata"]
 
 
@@ -1358,6 +1393,28 @@ def test_topic_stats_service_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.TopicStatsServiceGrpcTransport,
+        transports.TopicStatsServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_topic_stats_service_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1831,4 +1888,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
